==> Paws-0.26.tar.gz: Paws-0.26/lib/Paws/EC2/ClassicLinkDnsSupport.pm <==
package Paws::EC2::ClassicLinkDnsSupport;
  use Moose;
  has ClassicLinkDnsSupported => (is => 'ro', isa => 'Bool', xmlname => 'classicLinkDnsSupported', traits => ['Unwrapped']);
  has VpcId => (is => 'ro', isa => 'Str', xmlname => 'vpcId', traits => ['Unwrapped']);
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::ClassicLinkDnsSupport

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::EC2::ClassicLinkDnsSupport object:

  $service_obj->Method(Att1 => { ClassicLinkDnsSupported => $value, ..., VpcId => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::EC2::ClassicLinkDnsSupport object:

  $result = $service_obj->Method(...);
  $result->Att1->ClassicLinkDnsSupported

=head1 DESCRIPTION

This class has no description

=head1 ATTRIBUTES


=head2 ClassicLinkDnsSupported => Bool

  Indicates whether ClassicLink DNS support is enabled for the VPC.


=head2 VpcId => Str

  The ID of the VPC.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.34.tar.gz: Paws-0.34/lib/Paws/EC2/ClassicLinkDnsSupport.pm <==
package Paws::EC2::ClassicLinkDnsSupport;
  use Moose;
  has ClassicLinkDnsSupported => (is => 'ro', isa => 'Bool', request_name => 'classicLinkDnsSupported', traits => ['NameInRequest']);
  has VpcId => (is => 'ro', isa => 'Str', request_name => 'vpcId', traits => ['NameInRequest']);
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::ClassicLinkDnsSupport

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::EC2::ClassicLinkDnsSupport object:

  $service_obj->Method(Att1 => { ClassicLinkDnsSupported => $value, ..., VpcId => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::EC2::ClassicLinkDnsSupport object:

  $result = $service_obj->Method(...);
  $result->Att1->ClassicLinkDnsSupported

=head1 DESCRIPTION

This class has no description

=head1 ATTRIBUTES


=head2 ClassicLinkDnsSupported => Bool

  Indicates whether ClassicLink DNS support is enabled for the VPC.


=head2 VpcId => Str

  The ID of the VPC.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
